@@ -18,34 +18,6 @@
  */
 package org.apache.myfaces.context.servlet;
 
-import org.apache.myfaces.application.ResourceHandlerImpl;
-import org.apache.myfaces.context.PartialResponseWriterImpl;
-import org.apache.myfaces.context.RequestViewContext;
-import org.apache.myfaces.renderkit.html.HtmlResponseStateManager;
-import org.apache.myfaces.shared.renderkit.JSFAttr;
-import org.apache.myfaces.shared.util.StringUtils;
-
-import javax.faces.FactoryFinder;
-import javax.faces.component.EditableValueHolder;
-import javax.faces.component.UIComponent;
-import javax.faces.component.UIViewParameter;
-import javax.faces.component.UIViewRoot;
-import javax.faces.component.behavior.ClientBehaviorContext;
-import javax.faces.component.visit.VisitCallback;
-import javax.faces.component.visit.VisitContext;
-import javax.faces.component.visit.VisitContextFactory;
-import javax.faces.component.visit.VisitHint;
-import javax.faces.component.visit.VisitResult;
-import javax.faces.context.ExternalContext;
-import javax.faces.context.FacesContext;
-import javax.faces.context.PartialResponseWriter;
-import javax.faces.context.PartialViewContext;
-import javax.faces.context.ResponseWriter;
-import javax.faces.event.PhaseId;
-import javax.faces.lifecycle.ClientWindow;
-import javax.faces.render.RenderKit;
-import javax.faces.render.RenderKitFactory;
-import javax.faces.view.ViewMetadata;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -57,67 +29,75 @@ import java.util.Set;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
+import jakarta.faces.FactoryFinder;
+import jakarta.faces.component.UIComponent;
+import jakarta.faces.component.UIViewParameter;
+import jakarta.faces.component.UIViewRoot;
+import jakarta.faces.component.behavior.ClientBehaviorContext;
+import jakarta.faces.component.visit.VisitCallback;
+import jakarta.faces.component.visit.VisitContext;
+import jakarta.faces.component.visit.VisitContextFactory;
+import jakarta.faces.component.visit.VisitHint;
+import jakarta.faces.component.visit.VisitResult;
+import jakarta.faces.context.ExternalContext;
+import jakarta.faces.context.FacesContext;
+import jakarta.faces.context.PartialResponseWriter;
+import jakarta.faces.context.PartialViewContext;
+import jakarta.faces.context.ResponseWriter;
+import jakarta.faces.event.PhaseId;
+import jakarta.faces.lifecycle.ClientWindow;
+import jakarta.faces.render.RenderKit;
+import jakarta.faces.render.RenderKitFactory;
+import jakarta.faces.view.ViewMetadata;
+import org.apache.myfaces.application.ResourceHandlerImpl;
+import org.apache.myfaces.application.viewstate.StateTokenProcessor;
+
+import org.apache.myfaces.context.PartialResponseWriterImpl;
+import org.apache.myfaces.context.RequestViewContext;
+import org.apache.myfaces.renderkit.html.HtmlResponseStateManager;
+import org.apache.myfaces.renderkit.html.util.ResourceUtils;
+import org.apache.myfaces.util.lang.StringUtils;
+import org.apache.myfaces.component.visit.MyFacesVisitHints;
+import org.apache.myfaces.renderkit.html.util.ComponentAttrs;
+
 public class PartialViewContextImpl extends PartialViewContext
 {
+    private static final Logger log = Logger.getLogger(PartialViewContextImpl.class.getName());
 
     private static final String FACES_REQUEST = "Faces-Request";
     private static final String PARTIAL_AJAX = "partial/ajax";
-    private static final String PARTIAL_AJAX_REQ = "javax.faces.partial.ajax";
+    private static final String PARTIAL_AJAX_REQ = "jakarta.faces.partial.ajax";
     private static final String PARTIAL_PROCESS = "partial/process";
-
-    /**
-     * Internal extension for
-     * https://issues.apache.org/jira/browse/MYFACES-2841
-     * will be changed for 2.1 to the official marker
-     */
-    private static final String PARTIAL_IFRAME = "org.apache.myfaces.partial.iframe";
     
-    private static final  Set<VisitHint> PARTIAL_EXECUTE_HINTS = Collections.unmodifiableSet( 
+    private static final Set<VisitHint> PARTIAL_EXECUTE_HINTS = Collections.unmodifiableSet( 
             EnumSet.of(VisitHint.EXECUTE_LIFECYCLE, VisitHint.SKIP_UNRENDERED));
-    
-    // unrendered have to be skipped, transient definitely must be added to our list!
-    private static final  Set<VisitHint> PARTIAL_RENDER_HINTS = 
-            Collections.unmodifiableSet(EnumSet.of(VisitHint.SKIP_UNRENDERED));
 
-    private static final VisitCallback RESET_VALUES_CALLBACK = new ResetValuesCallback();
-
-    private static final  Set<VisitHint> RESET_VALUES_HINTS =
-            Collections.unmodifiableSet(EnumSet.of(VisitHint.SKIP_UNRENDERED));
-
-    private FacesContext _facesContext = null;
+    private FacesContext context = null;
     private boolean _released = false;
     // Cached values, since their parent methods could be called
     // many times and the result does not change during the life time
     // of this object.
     private Boolean _ajaxRequest = null;
 
-    /**
-     * Internal extension for
-     * https://issues.apache.org/jira/browse/MYFACES-2841
-     * will be changed for 2.1 to the official marker
-     */
-    private Boolean _iframeRequest = null;
-
     private Collection<String> _executeClientIds = null;
     private Collection<String> _renderClientIds = null;
     // Values that need to be saved because exists a setXX method 
     private Boolean _partialRequest = null;
     private Boolean _renderAll = null;
     private PartialResponseWriter _partialResponseWriter = null;
-    private VisitContextFactory _visitContextFactory = null;
+    private VisitContextFactory visitContextFactory = null;
     private Boolean _resetValues = null;
-    private List<String> _evalScripts = new ArrayList<String>();
+    private List<String> _evalScripts = new ArrayList<>();
 
     public PartialViewContextImpl(FacesContext context)
     {
-        _facesContext = context;
+        this.context = context;
     }
     
-    public PartialViewContextImpl(FacesContext context, 
-            VisitContextFactory visitContextFactory)
+    public PartialViewContextImpl(FacesContext context, VisitContextFactory visitContextFactory)
     {
-        _facesContext = context;
-        _visitContextFactory = visitContextFactory;
+        this.context = context;
+        this.visitContextFactory = visitContextFactory;
     }
 
     @Override
@@ -126,12 +106,11 @@ public class PartialViewContextImpl extends PartialViewContext
         assertNotReleased();
         if (_ajaxRequest == null)
         {
-            String requestType = _facesContext.getExternalContext().
-                   getRequestHeaderMap().get(FACES_REQUEST);
+            String requestType = context.getExternalContext().getRequestHeaderMap().get(FACES_REQUEST);
             _ajaxRequest = (requestType != null && PARTIAL_AJAX.equals(requestType));
-            String reqParmamterPartialAjax = _facesContext.getExternalContext().
-                    getRequestParameterMap().get(PARTIAL_AJAX_REQ);
-            //jsdoc reference in an ajax request the javax.faces.partial.ajax must be set as ajax parameter
+            String reqParmamterPartialAjax = context.getExternalContext()
+                    .getRequestParameterMap().get(PARTIAL_AJAX_REQ);
+            //jsdoc reference in an ajax request the jakarta.faces.partial.ajax must be set as ajax parameter
             //the other one is Faces-Request == partial/ajax which is basically the same
             _ajaxRequest = _ajaxRequest || reqParmamterPartialAjax != null;
         }
@@ -145,9 +124,8 @@ public class PartialViewContextImpl extends PartialViewContext
 
         if (isAjaxRequest())
         {
-            String executeMode = _facesContext.getExternalContext().
-                    getRequestParameterMap().get(
-                    PartialViewContext.PARTIAL_EXECUTE_PARAM_NAME);
+            String executeMode = context.getExternalContext().
+                    getRequestParameterMap().get(PartialViewContext.PARTIAL_EXECUTE_PARAM_NAME);
             if (PartialViewContext.ALL_PARTIAL_PHASE_CLIENT_IDS.equals(executeMode))
             {
                 return true;
@@ -163,8 +141,7 @@ public class PartialViewContextImpl extends PartialViewContext
 
         if (_partialRequest == null)
         {
-            String requestType = _facesContext.getExternalContext().
-                    getRequestHeaderMap().get(FACES_REQUEST);
+            String requestType = context.getExternalContext().getRequestHeaderMap().get(FACES_REQUEST);
             _partialRequest = (requestType != null && PARTIAL_PROCESS.equals(requestType));
         }
         return _partialRequest || isAjaxRequest();
@@ -179,9 +156,8 @@ public class PartialViewContextImpl extends PartialViewContext
         {
             if (isAjaxRequest())
             {
-                String executeMode = _facesContext.getExternalContext().
-                        getRequestParameterMap().get(
-                        PartialViewContext.PARTIAL_RENDER_PARAM_NAME);
+                String executeMode = context.getExternalContext().
+                        getRequestParameterMap().get(PartialViewContext.PARTIAL_RENDER_PARAM_NAME);
                 if (PartialViewContext.ALL_PARTIAL_PHASE_CLIENT_IDS.equals(executeMode))
                 {
                     _renderAll = true;
@@ -195,30 +171,12 @@ public class PartialViewContextImpl extends PartialViewContext
         return _renderAll;
     }
 
-    /**
-     * Extension for
-     * https://issues.apache.org/jira/browse/MYFACES-2841
-     * internal extension which detects that the submit is an iframe request
-     * will be changed for the official version which will come in 2.1
-     *
-     * @return true if the current request is an iframe based ajax request
-     */
-    public boolean isIFrameRequest()
-    {
-        if (_iframeRequest == null)
-        {
-            _iframeRequest = _facesContext.getExternalContext().getRequestParameterMap().containsKey(PARTIAL_IFRAME);
-        }
-        return _iframeRequest;
-    }
-
     @Override
     public void setPartialRequest(boolean isPartialRequest)
     {
         assertNotReleased();
 
         _partialRequest = isPartialRequest;
-
     }
 
     @Override
@@ -236,20 +194,18 @@ public class PartialViewContextImpl extends PartialViewContext
 
         if (_executeClientIds == null)
         {
-            String executeMode = _facesContext.getExternalContext().
-                    getRequestParameterMap().get(
-                    PartialViewContext.PARTIAL_EXECUTE_PARAM_NAME);
+            String executeMode = context.getExternalContext().
+                    getRequestParameterMap().get(PartialViewContext.PARTIAL_EXECUTE_PARAM_NAME);
 
-            if (executeMode != null && !"".equals(executeMode) &&
-                    //!PartialViewContext.NO_PARTIAL_PHASE_CLIENT_IDS.equals(executeMode) &&
-                    !PartialViewContext.ALL_PARTIAL_PHASE_CLIENT_IDS.equals(executeMode))
+            if (executeMode != null && !executeMode.isEmpty()
+                    && !PartialViewContext.ALL_PARTIAL_PHASE_CLIENT_IDS.equals(executeMode))
             {
 
                 String[] clientIds
                         = StringUtils.splitShortString(_replaceTabOrEnterCharactersWithSpaces(executeMode), ' ');
 
                 //The collection must be mutable
-                List<String> tempList = new ArrayList<String>();
+                List<String> tempList = new ArrayList<>(clientIds.length);
                 for (String clientId : clientIds)
                 {
                     if (clientId.length() > 0)
@@ -257,11 +213,11 @@ public class PartialViewContextImpl extends PartialViewContext
                         tempList.add(clientId);
                     }
                 }
-                // The "javax.faces.source" parameter needs to be added to the list of
+                // The "jakarta.faces.source" parameter needs to be added to the list of
                 // execute ids if missing (otherwise, we'd never execute an action associated
                 // with, e.g., a button).
 
-                String source = _facesContext.getExternalContext().getRequestParameterMap().get
+                String source = context.getExternalContext().getRequestParameterMap().get
                         (ClientBehaviorContext.BEHAVIOR_SOURCE_PARAM_NAME);
 
                 if (source != null)
@@ -278,7 +234,7 @@ public class PartialViewContextImpl extends PartialViewContext
             }
             else
             {
-                _executeClientIds = new ArrayList<String>();
+                _executeClientIds = new ArrayList<>(5);
             }
         }
         return _executeClientIds;
@@ -286,20 +242,33 @@ public class PartialViewContextImpl extends PartialViewContext
 
     private String _replaceTabOrEnterCharactersWithSpaces(String mode)
     {
-        StringBuilder builder = new StringBuilder(mode.length());
-        for (int i = 0; i < mode.length(); i++)
+        if (mode == null)
         {
-            if (mode.charAt(i) == '\t' ||
-                    mode.charAt(i) == '\n')
+            return null;
+        }
+        
+        char[] escaped = null;
+        
+        int modeLength = mode.length();
+        for (int i = 0; i < modeLength; i++)
+        {
+            char c = mode.charAt(i);
+            if (c == '\t' || c == '\n')
             {
-                builder.append(' ');
-            }
-            else
-            {
-                builder.append(mode.charAt(i));
+                if (escaped == null)
+                {
+                    escaped = mode.toCharArray();
+                }
+                escaped[i] = ' ';
             }
         }
-        return builder.toString();
+
+        if (escaped != null)
+        {
+            return String.valueOf(escaped);
+        }
+        
+        return mode;
     }
 
     @Override
@@ -309,19 +278,18 @@ public class PartialViewContextImpl extends PartialViewContext
 
         if (_renderClientIds == null)
         {
-            String renderMode = _facesContext.getExternalContext().
+            String renderMode = context.getExternalContext().
                     getRequestParameterMap().get(
                     PartialViewContext.PARTIAL_RENDER_PARAM_NAME);
 
-            if (renderMode != null && !"".equals(renderMode) &&
-                    //!PartialViewContext.NO_PARTIAL_PHASE_CLIENT_IDS.equals(renderMode) &&
-                    !PartialViewContext.ALL_PARTIAL_PHASE_CLIENT_IDS.equals(renderMode))
+            if (renderMode != null && !renderMode.isEmpty()
+                    && !PartialViewContext.ALL_PARTIAL_PHASE_CLIENT_IDS.equals(renderMode))
             {
                 String[] clientIds
                         = StringUtils.splitShortString(_replaceTabOrEnterCharactersWithSpaces(renderMode), ' ');
 
                 //The collection must be mutable
-                List<String> tempList = new ArrayList<String>();
+                List<String> tempList = new ArrayList<>(clientIds.length);
                 for (String clientId : clientIds)
                 {
                     if (clientId.length() > 0)
@@ -333,8 +301,7 @@ public class PartialViewContextImpl extends PartialViewContext
             }
             else
             {
-                _renderClientIds = new ArrayList<String>();
-
+                _renderClientIds = new ArrayList<>(5);
                 if (PartialViewContext.ALL_PARTIAL_PHASE_CLIENT_IDS.equals(renderMode))
                 {
                     _renderClientIds.add(PartialResponseWriter.RENDER_ALL_MARKER);
@@ -351,7 +318,7 @@ public class PartialViewContextImpl extends PartialViewContext
 
         if (_partialResponseWriter == null)
         {
-            ResponseWriter responseWriter = _facesContext.getResponseWriter();
+            ResponseWriter responseWriter = context.getResponseWriter();
             if (responseWriter == null)
             {
                 // This case happens when getPartialResponseWriter() is called before
@@ -359,7 +326,7 @@ public class PartialViewContextImpl extends PartialViewContext
                 // ResponseWriter from the RenderKit and then wrap if necessary. 
                 try
                 {
-                    RenderKit renderKit = _facesContext.getRenderKit();
+                    RenderKit renderKit = context.getRenderKit();
                     if (renderKit == null)
                     {
                         // If the viewRoot was set to null by some reason, or there is no 
@@ -367,14 +334,14 @@ public class PartialViewContextImpl extends PartialViewContext
                         // so we have to try to calculate the renderKitId and return a 
                         // RenderKit instance, to send the response.
                         String renderKitId
-                                = _facesContext.getApplication().getViewHandler().calculateRenderKitId(_facesContext);
+                                = context.getApplication().getViewHandler().calculateRenderKitId(context);
                         RenderKitFactory rkf
                                 = (RenderKitFactory) FactoryFinder.getFactory(FactoryFinder.RENDER_KIT_FACTORY);
-                        renderKit = rkf.getRenderKit(_facesContext, renderKitId);
+                        renderKit = rkf.getRenderKit(context, renderKitId);
                     }
                     responseWriter = renderKit.createResponseWriter(
-                            _facesContext.getExternalContext().getResponseOutputWriter(), "text/xml",
-                            _facesContext.getExternalContext().getRequestCharacterEncoding());
+                            context.getExternalContext().getResponseOutputWriter(), "text/xml",
+                            context.getExternalContext().getRequestCharacterEncoding());
                 }
                 catch (IOException e)
                 {
@@ -412,7 +379,7 @@ public class PartialViewContextImpl extends PartialViewContext
     {
         assertNotReleased();
 
-        UIViewRoot viewRoot = _facesContext.getViewRoot();
+        UIViewRoot viewRoot = context.getViewRoot();
 
         if (phaseId == PhaseId.APPLY_REQUEST_VALUES
                 || phaseId == PhaseId.PROCESS_VALIDATIONS
@@ -428,43 +395,31 @@ public class PartialViewContextImpl extends PartialViewContext
 
     private void processPartialExecute(UIViewRoot viewRoot, PhaseId phaseId)
     {
-        PartialViewContext pvc = _facesContext.getPartialViewContext();
+        PartialViewContext pvc = context.getPartialViewContext();
         Collection<String> executeIds = pvc.getExecuteIds();
         if (executeIds == null || executeIds.isEmpty())
         {
             return;
         }
         
-        VisitContext visitCtx = getVisitContextFactory().getVisitContext(_facesContext, executeIds, 
+        VisitContext visitCtx = getVisitContextFactory().getVisitContext(context, executeIds, 
                 PARTIAL_EXECUTE_HINTS);
-        viewRoot.visitTree(visitCtx, new PhaseAwareVisitCallback(_facesContext, phaseId));
+        viewRoot.visitTree(visitCtx, new PhaseAwareVisitCallback(context, phaseId));
     }
 
     private void processPartialRendering(UIViewRoot viewRoot, PhaseId phaseId)
     {
-        //TODO process partial rendering
-        //https://issues.apache.org/jira/browse/MYFACES-2118
-        //Collection<String> renderIds = getRenderIds();
-
-        // We need to always update the view state marker when processing partial
-        // rendering, because there is no way to check when the state has been changed
-        // or not. Anyway, if we return empty response, according to the spec a javascript
-        // message displayed, so we need to return something.
-        //if (renderIds == null || renderIds.isEmpty()) {
-        //    return;
-        //}
-
         // note that we cannot use this.getPartialResponseWriter(), because
         // this could cause problems if PartialResponseWriter is wrapped
-        PartialResponseWriter writer = _facesContext.getPartialViewContext().getPartialResponseWriter();
-        PartialViewContext pvc = _facesContext.getPartialViewContext();
+        PartialResponseWriter writer = context.getPartialViewContext().getPartialResponseWriter();
+        PartialViewContext pvc = context.getPartialViewContext();
 
-        ResponseWriter oldWriter = _facesContext.getResponseWriter();
+        ResponseWriter oldWriter = context.getResponseWriter();
         boolean inDocument = false;
 
         //response type = text/xml
         //no caching and no timeout if possible!
-        ExternalContext externalContext = _facesContext.getExternalContext();
+        ExternalContext externalContext = context.getExternalContext();
         externalContext.setResponseContentType("text/xml");
         externalContext.addResponseHeader("Pragma", "no-cache");
         externalContext.addResponseHeader("Cache-control", "no-cache");
@@ -475,20 +430,16 @@ public class PartialViewContextImpl extends PartialViewContext
 
         try
         {
-            String currentEncoding = writer.getCharacterEncoding();
-
             writer.startDocument();
             
-            writer.writeAttribute("id", viewRoot.getContainerClientId(_facesContext),"id");
+            writer.writeAttribute("id", viewRoot.getContainerClientId(context),"id");
             
             inDocument = true;
-            _facesContext.setResponseWriter(writer);
+            context.setResponseWriter(writer);
             
             if (isResetValues())
             {
-                VisitContext visitContext = VisitContext.createVisitContext(_facesContext, getRenderIds(),
-                        RESET_VALUES_HINTS);
-                viewRoot.visitTree(visitContext, RESET_VALUES_CALLBACK);
+                viewRoot.resetValues(context, getRenderIds());
             }
 
             if (pvc.isRenderAll())
@@ -508,34 +459,32 @@ public class PartialViewContextImpl extends PartialViewContext
                     }
                     else
                     {
-                        // In JSF 2.3 it was added javax.faces.Resource as an update target to add scripts or
-                        // stylesheets inside <head> tag. In that sense 
-                        // org.apache.myfaces.STRICT_JSF_2_REFRESH_TARGET_AJAX web config param, which was a 
-                        // workaround for dynamic refresh can be deprecated.
+                        // In Faces 2.3 it was added jakarta.faces.Resource as an update target to add scripts or
+                        // stylesheets inside <head> tag
                         
-                        List<UIComponent> updatedComponents = new ArrayList<UIComponent>();
-                        RequestViewContext rvc = RequestViewContext.getCurrentInstance(_facesContext);
-                        processRenderResource(_facesContext, writer, rvc, updatedComponents, "head");
-                        processRenderResource(_facesContext, writer, rvc, updatedComponents, "body");
-                        processRenderResource(_facesContext, writer, rvc, updatedComponents, "form");
+                        List<UIComponent> updatedComponents = new ArrayList<>();
+                        RequestViewContext rvc = RequestViewContext.getCurrentInstance(context);
+                        processRenderResource(context, writer, rvc, updatedComponents, "head");
+                        processRenderResource(context, writer, rvc, updatedComponents, "body");
+                        processRenderResource(context, writer, rvc, updatedComponents, "form");
 
-                        VisitContext visitCtx = getVisitContextFactory().getVisitContext(
-                                _facesContext, renderIds, PARTIAL_RENDER_HINTS);
+                        VisitContext visitCtx = getVisitContextFactory().getVisitContext(context, renderIds,
+                                MyFacesVisitHints.SET_SKIP_UNRENDERED);
                         viewRoot.visitTree(visitCtx,
-                                           new PhaseAwareVisitCallback(_facesContext, phaseId, updatedComponents));
+                                           new PhaseAwareVisitCallback(context, phaseId, updatedComponents));
                     }
                 }
                 else
                 {
-                    List<UIComponent> updatedComponents = new ArrayList<UIComponent>();
-                    RequestViewContext rvc = RequestViewContext.getCurrentInstance(_facesContext);
-                    processRenderResource(_facesContext, writer, rvc, updatedComponents, "head");
-                    processRenderResource(_facesContext, writer, rvc, updatedComponents, "body");
-                    processRenderResource(_facesContext, writer, rvc, updatedComponents, "form");
+                    List<UIComponent> updatedComponents = new ArrayList<>();
+                    RequestViewContext rvc = RequestViewContext.getCurrentInstance(context);
+                    processRenderResource(context, writer, rvc, updatedComponents, "head");
+                    processRenderResource(context, writer, rvc, updatedComponents, "body");
+                    processRenderResource(context, writer, rvc, updatedComponents, "form");
                 }
                 
                 List<String> evalScripts = pvc.getEvalScripts();
-                if (evalScripts != null && evalScripts.size() > 0)
+                if (evalScripts != null && !evalScripts.isEmpty())
                 {
                     for (String script : evalScripts)
                     {
@@ -555,47 +504,40 @@ public class PartialViewContextImpl extends PartialViewContext
             {
                 for (UIViewParameter param : viewParams)
                 {
-                    param.encodeAll(_facesContext);
+                    param.encodeAll(context);
                 }
             }
 
             //Retrieve the state and apply it if it is not null.
-            String viewState = _facesContext.getApplication().getStateManager().getViewState(_facesContext);
+            String viewState = context.getApplication().getStateManager().getViewState(context);
             if (viewState != null)
             {
-                writer.startUpdate(HtmlResponseStateManager.generateUpdateViewStateId(
-                    _facesContext));
+                writer.startUpdate(HtmlResponseStateManager.generateUpdateViewStateId(context));
                 writer.write(viewState);
                 writer.endUpdate();
             }
             else if (viewRoot.isTransient())
             {
-                //TODO: fix javascript side, so the field is not removed on ajax form update
-                writer.startUpdate(HtmlResponseStateManager.generateUpdateViewStateId(
-                    _facesContext));
-                writer.write("stateless");
+                writer.startUpdate(HtmlResponseStateManager.generateUpdateViewStateId(context));
+                writer.write(StateTokenProcessor.STATELESS_TOKEN);
                 writer.endUpdate();
-                //END TODO
             }
             
             
-            ClientWindow cw = _facesContext.getExternalContext().getClientWindow();
+            ClientWindow cw = context.getExternalContext().getClientWindow();
             if (cw != null)
             {
-                writer.startUpdate(HtmlResponseStateManager.generateUpdateClientWindowId(
-                    _facesContext));
-                writer.write(cw.getId());
+                writer.startUpdate(HtmlResponseStateManager.generateUpdateClientWindowId(context));
+                writer.writeText(cw.getId(), null);
                 writer.endUpdate();
             }
         }
         catch (IOException ex)
         {
-            Logger log = Logger.getLogger(PartialViewContextImpl.class.getName());
             if (log.isLoggable(Level.SEVERE))
             {
                 log.log(Level.SEVERE, "", ex);
             }
-
         }
         finally
         {
@@ -609,31 +551,17 @@ public class PartialViewContextImpl extends PartialViewContext
             }
             catch (IOException ex)
             {
-                Logger log = Logger.getLogger(PartialViewContextImpl.class.getName());
                 if (log.isLoggable(Level.SEVERE))
                 {
                     log.log(Level.SEVERE, "", ex);
                 }
             }
 
-            _facesContext.setResponseWriter(oldWriter);
+            context.setResponseWriter(oldWriter);
         }
 
     }
-
-    // same like UIViewRoot#ResetValuesCallback
-    private static class ResetValuesCallback implements VisitCallback
-    {
-        public VisitResult visit(VisitContext context, UIComponent target)
-        {
-            if (target instanceof EditableValueHolder)
-            {
-                ((EditableValueHolder)target).resetValue();
-            }
-            return VisitResult.ACCEPT;
-        }
-    }
-
+    
     private void processRenderResource(FacesContext facesContext, PartialResponseWriter writer, RequestViewContext rvc, 
             List<UIComponent> updatedComponents, String target) throws IOException
     {
@@ -642,25 +570,17 @@ public class PartialViewContextImpl extends PartialViewContext
             List<UIComponent> list = rvc.getRenderTargetComponentList(target);
             if (list != null && !list.isEmpty())
             {
-                writer.startUpdate("javax.faces.Resource");
+                writer.startUpdate("jakarta.faces.Resource");
                 for (UIComponent component : list)
                 {
                     boolean resourceRendered = false;
-                    if ("javax.faces.resource.Script".equals(component.getRendererType()) ||
-                        "javax.faces.resource.Stylesheet".equals(component.getRendererType()))
+                    if (ResourceUtils.DEFAULT_SCRIPT_RENDERER_TYPE.equals(component.getRendererType())
+                            || ResourceUtils.DEFAULT_STYLESHEET_RENDERER_TYPE.equals(component.getRendererType()))
                     {
-                        String resourceName = (String) 
-                                component.getAttributes().get(JSFAttr.NAME_ATTR);
-                        String libraryName = (String) 
-                                component.getAttributes().get(JSFAttr.LIBRARY_ATTR);
+                        String resourceName = (String) component.getAttributes().get(ComponentAttrs.NAME_ATTR);
+                        String libraryName = (String) component.getAttributes().get(ComponentAttrs.LIBRARY_ATTR);
 
-                        if (resourceName == null)
-                        {
-                            // No resource, render all
-                            component.encodeAll(facesContext);
-                            continue;
-                        }
-                        if ("".equals(resourceName))
+                        if (resourceName == null || resourceName.isEmpty())
                         {
                             // No resource, render all
                             component.encodeAll(facesContext);
@@ -673,8 +593,8 @@ public class PartialViewContextImpl extends PartialViewContext
                             resourceName = resourceName.substring(0, index);
                         }
                         // Is resource, render only if it has not been rendered before.
-                        if (!_facesContext.getApplication().getResourceHandler().isResourceRendered(
-                                _facesContext, resourceName, libraryName))
+                        if (!context.getApplication().getResourceHandler().isResourceRendered(
+                                context, resourceName, libraryName))
                         {
                             component.encodeAll(facesContext);
                         }
@@ -687,7 +607,7 @@ public class PartialViewContextImpl extends PartialViewContext
                     {
                         if (updatedComponents == null)
                         {
-                            updatedComponents = new ArrayList<UIComponent>();
+                            updatedComponents = new ArrayList<>();
                         }
                         updatedComponents.add(component);
                     }
@@ -713,7 +633,7 @@ public class PartialViewContextImpl extends PartialViewContext
         for (int i = 0, childCount = viewRoot.getChildCount(); i < childCount; i++)
         {
             UIComponent comp = viewRoot.getChildren().get(i);
-            comp.encodeAll(_facesContext);
+            comp.encodeAll(context);
         }
         writer.endUpdate();
     }
@@ -733,23 +653,23 @@ public class PartialViewContextImpl extends PartialViewContext
     public void release()
     {
         assertNotReleased();
-        _visitContextFactory = null;
+        visitContextFactory = null;
         _executeClientIds = null;
         _renderClientIds = null;
         _ajaxRequest = null;
         _partialRequest = null;
         _renderAll = null;
-        _facesContext = null;
+        context = null;
         _released = true;
     }
     
     private VisitContextFactory getVisitContextFactory()
     {
-        if (_visitContextFactory == null)
+        if (visitContextFactory == null)
         {
-            _visitContextFactory = (VisitContextFactory)FactoryFinder.getFactory(FactoryFinder.VISIT_CONTEXT_FACTORY);
+            visitContextFactory = (VisitContextFactory)FactoryFinder.getFactory(FactoryFinder.VISIT_CONTEXT_FACTORY);
         }
-        return _visitContextFactory;
+        return visitContextFactory;
     }
 
     @Override
@@ -757,7 +677,7 @@ public class PartialViewContextImpl extends PartialViewContext
     {
         if (_resetValues == null)
         {
-            String value = _facesContext.getExternalContext().getRequestParameterMap().
+            String value = context.getExternalContext().getRequestParameterMap().
                 get(RESET_VALUES_PARAM_NAME);
             _resetValues = "true".equals(value);
         }
@@ -766,7 +686,6 @@ public class PartialViewContextImpl extends PartialViewContext
 
     private class PhaseAwareVisitCallback implements VisitCallback
     {
-
         private PhaseId _phaseId;
         private FacesContext _facesContext;
         private List<UIComponent> _alreadyUpdatedComponents;
@@ -846,7 +765,6 @@ public class PartialViewContextImpl extends PartialViewContext
             }
             catch (IOException ex)
             {
-                Logger log = Logger.getLogger(PartialViewContextImpl.class.getName());
                 if (log.isLoggable(Level.SEVERE))
                 {
                     log.log(Level.SEVERE, "IOException for rendering component", ex);
@@ -862,7 +780,6 @@ public class PartialViewContextImpl extends PartialViewContext
                     }
                     catch (IOException ex)
                     {
-                        Logger log = Logger.getLogger(PartialViewContextImpl.class.getName());
                         if (log.isLoggable(Level.SEVERE))
                         {
                             log.log(Level.SEVERE, "IOException for rendering component, stopping update rendering", ex);
