@@ -20,15 +20,16 @@ package org.apache.myfaces.view.facelets.tag;
 
 import java.util.Arrays;
 
-import javax.el.ELException;
-import javax.el.ExpressionFactory;
-import javax.el.MethodExpression;
-import javax.el.ValueExpression;
-import javax.faces.component.UIComponent;
-import javax.faces.view.Location;
-import javax.faces.view.facelets.FaceletContext;
-import javax.faces.view.facelets.TagAttribute;
-import javax.faces.view.facelets.TagAttributeException;
+import jakarta.el.ELException;
+import jakarta.el.ExpressionFactory;
+import jakarta.el.MethodExpression;
+import jakarta.el.ValueExpression;
+import jakarta.faces.component.UIComponent;
+import jakarta.faces.view.Location;
+import jakarta.faces.view.facelets.FaceletContext;
+import jakarta.faces.view.facelets.TagAttribute;
+import jakarta.faces.view.facelets.TagAttributeException;
+import org.apache.myfaces.resource.ResourceELUtils;
 
 import org.apache.myfaces.view.facelets.AbstractFaceletContext;
 import org.apache.myfaces.view.facelets.el.CompositeComponentELUtils;
@@ -37,7 +38,6 @@ import org.apache.myfaces.view.facelets.el.ContextAwareTagValueExpression;
 import org.apache.myfaces.view.facelets.el.ELText;
 import org.apache.myfaces.view.facelets.el.LocationMethodExpression;
 import org.apache.myfaces.view.facelets.el.LocationValueExpression;
-import org.apache.myfaces.view.facelets.el.ResourceELUtils;
 import org.apache.myfaces.view.facelets.el.ResourceLocationValueExpression;
 import org.apache.myfaces.view.facelets.el.TagMethodExpression;
 import org.apache.myfaces.view.facelets.el.TagValueExpression;
@@ -53,7 +53,7 @@ public final class TagAttributeImpl extends TagAttribute
 {
 
     private final static int EL_LITERAL = 1;
-    
+   
     private final static int EL_CC = 2;
     
     private final static int EL_CC_ATTR_ME = 4;
@@ -61,17 +61,11 @@ public final class TagAttributeImpl extends TagAttribute
     private final static int EL_RESOURCE = 8;
     
     private final int capabilities;
-
     private final String localName;
-
     private final Location location;
-
     private final String namespace;
-
     private final String qName;
-
     private final String value;
-
     private String string;
 
     /**
@@ -106,16 +100,20 @@ public final class TagAttributeImpl extends TagAttribute
             throw new TagAttributeException(this, e);
         }
         
-        compositeComponentExpression = !literal ? 
-                CompositeComponentELUtils.isCompositeComponentExpression(this.value) : 
-                    false;
-        compositeComponentAttrMethodExpression = compositeComponentExpression ? 
-                CompositeComponentELUtils.isCompositeComponentAttrsMethodExpression(this.value) : 
-                    false;
-        resourceExpression = !literal ? ResourceELUtils.isResourceExpression(this.value) : false;
+        compositeComponentExpression = !literal
+                ? CompositeComponentELUtils.isCompositeComponentExpression(this.value)
+                : false;
+        compositeComponentAttrMethodExpression = compositeComponentExpression
+                ? CompositeComponentELUtils.isCompositeComponentAttrsMethodExpression(this.value)
+                : false;
+        resourceExpression = !literal
+                ? ResourceELUtils.isResourceExpression(this.value)
+                : false;
 
-        this.capabilities = (literal ? EL_LITERAL : 0) | (compositeComponentExpression ? EL_CC : 0) | 
-            (compositeComponentAttrMethodExpression ? EL_CC_ATTR_ME : 0) | ( resourceExpression ? EL_RESOURCE : 0); 
+        this.capabilities = (literal ? EL_LITERAL : 0)
+                | (compositeComponentExpression ? EL_CC : 0)
+                | (compositeComponentAttrMethodExpression ? EL_CC_ATTR_ME : 0)
+                | (resourceExpression ? EL_RESOURCE : 0); 
     }
 
     /**
@@ -128,15 +126,21 @@ public final class TagAttributeImpl extends TagAttribute
      *            FaceletContext to use
      * @return boolean value
      */
+    @Override
     public boolean getBoolean(FaceletContext ctx)
     {
         if ((this.capabilities & EL_LITERAL) != 0)
         {
-            return Boolean.valueOf(this.value).booleanValue();
+            return Boolean.valueOf(this.value);
         }
         else
         {
-            return ((Boolean) this.getObject(ctx, Boolean.class)).booleanValue();
+            Boolean result = ((Boolean) this.getObject(ctx, Boolean.class));
+            if(result == null)
+            {
+                return false;
+            }
+            return result;
         }
     }
 
@@ -150,6 +154,7 @@ public final class TagAttributeImpl extends TagAttribute
      *            FaceletContext to use
      * @return int value
      */
+    @Override
     public int getInt(FaceletContext ctx)
     {
         if ((this.capabilities & EL_LITERAL) != 0)
@@ -167,6 +172,7 @@ public final class TagAttributeImpl extends TagAttribute
      * 
      * @return local name of this attribute
      */
+    @Override
     public String getLocalName()
     {
         return this.localName;
@@ -177,6 +183,7 @@ public final class TagAttributeImpl extends TagAttribute
      * 
      * @return the TagAttribute's location
      */
+    @Override
     public Location getLocation()
     {
         return this.location;
@@ -185,7 +192,7 @@ public final class TagAttributeImpl extends TagAttribute
     /**
      * Create a MethodExpression, using this attribute's value as the expression String.
      * 
-     * See ExpressionFactory#createMethodExpression(javax.el.ELContext, java.lang.String, java.lang.Class,
+     * See ExpressionFactory#createMethodExpression(jakarta.el.ELContext, java.lang.String, java.lang.Class,
      *      java.lang.Class[])
      * See MethodExpression
      * @param ctx
@@ -196,6 +203,7 @@ public final class TagAttributeImpl extends TagAttribute
      *            parameter type
      * @return a MethodExpression instance
      */
+    @Override
     public MethodExpression getMethodExpression(FaceletContext ctx, Class type, Class[] paramTypes)
     {
         AbstractFaceletContext actx = (AbstractFaceletContext) ctx;
@@ -323,10 +331,7 @@ public final class TagAttributeImpl extends TagAttribute
                     array[0] = type;
                     array[1] = paramTypes;
                     array[2] = methodExpression;
-                    for (int i = 0; i < localCachedExpression.length; i++)
-                    {
-                        array[i+3] = localCachedExpression[i];
-                    }
+                    System.arraycopy(localCachedExpression, 0, array, 3, localCachedExpression.length);
                     cachedExpression = array;
                 }
                 else
@@ -352,6 +357,7 @@ public final class TagAttributeImpl extends TagAttribute
      * 
      * @return resolved Namespace
      */
+    @Override
     public String getNamespace()
     {
         return this.namespace;
@@ -365,6 +371,7 @@ public final class TagAttributeImpl extends TagAttribute
      *            FaceletContext to use
      * @return Object representation of this attribute's value
      */
+    @Override
     public Object getObject(FaceletContext ctx)
     {
         return this.getObject(ctx, Object.class);
@@ -375,6 +382,7 @@ public final class TagAttributeImpl extends TagAttribute
      * 
      * @return the qualified name for this attribute
      */
+    @Override
     public String getQName()
     {
         return this.qName;
@@ -385,6 +393,7 @@ public final class TagAttributeImpl extends TagAttribute
      * 
      * @return literal value
      */
+    @Override
     public String getValue()
     {
         return this.value;
@@ -398,6 +407,7 @@ public final class TagAttributeImpl extends TagAttribute
      *            FaceletContext to use
      * @return String value of this attribute
      */
+    @Override
     public String getValue(FaceletContext ctx)
     {
         if ((this.capabilities & EL_LITERAL) != 0)
@@ -415,7 +425,7 @@ public final class TagAttributeImpl extends TagAttribute
      * and evaluate it.
      * 
      * See ExpressionFactory#coerceToType(java.lang.Object, java.lang.Class)
-     * See ExpressionFactory#createValueExpression(javax.el.ELContext, java.lang.String, java.lang.Class)
+     * See ExpressionFactory#createValueExpression(jakarta.el.ELContext, java.lang.String, java.lang.Class)
      * See ValueExpression
      * @param ctx
      *            FaceletContext to use
@@ -423,6 +433,7 @@ public final class TagAttributeImpl extends TagAttribute
      *            expected return type
      * @return Object value of this attribute
      */
+    @Override
     public Object getObject(FaceletContext ctx, Class type)
     {
         if ((this.capabilities & EL_LITERAL) != 0)
@@ -460,7 +471,7 @@ public final class TagAttributeImpl extends TagAttribute
     /**
      * Create a ValueExpression, using this attribute's literal value and the passed expected type.
      * 
-     * See ExpressionFactory#createValueExpression(javax.el.ELContext, java.lang.String, java.lang.Class)
+     * See ExpressionFactory#createValueExpression(jakarta.el.ELContext, java.lang.String, java.lang.Class)
      * See ValueExpression
      * @param ctx
      *            FaceletContext to use
@@ -468,6 +479,7 @@ public final class TagAttributeImpl extends TagAttribute
      *            expected return type
      * @return ValueExpression instance
      */
+    @Override
     public ValueExpression getValueExpression(FaceletContext ctx, Class type)
     {
         AbstractFaceletContext actx = (AbstractFaceletContext) ctx;
@@ -592,6 +604,7 @@ public final class TagAttributeImpl extends TagAttribute
      * 
      * @return true if this attribute is literal
      */
+    @Override
     public boolean isLiteral()
     {
         return (this.capabilities & EL_LITERAL) != 0;
@@ -602,11 +615,12 @@ public final class TagAttributeImpl extends TagAttribute
      * 
      * See java.lang.Object#toString()
      */
+    @Override
     public String toString()
     {
         if (this.string == null)
         {
-            this.string = this.location + " " + this.qName + "=\"" + this.value + "\"";
+            this.string = this.location + " " + this.qName + "=\"" + this.value + '"';
         }
         return this.string;
     }
