@@ -21,26 +21,28 @@ package org.apache.myfaces.renderkit.html;
 import java.io.IOException;
 import java.io.StringWriter;
 
-import javax.el.ValueExpression;
-import javax.faces.component.UIComponent;
-import javax.faces.component.UIForm;
-import javax.faces.component.UIViewRoot;
-import javax.faces.component.behavior.AjaxBehavior;
-import javax.faces.component.html.HtmlInputText;
-import javax.faces.component.html.HtmlOutputText;
-import javax.faces.context.FacesContext;
-import javax.faces.convert.Converter;
-import javax.faces.convert.ConverterException;
-
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import jakarta.el.ValueExpression;
+import jakarta.faces.component.UIComponent;
+import jakarta.faces.component.UIForm;
+import jakarta.faces.component.UIViewRoot;
+import jakarta.faces.component.behavior.AjaxBehavior;
+import jakarta.faces.component.html.HtmlInputText;
+import jakarta.faces.component.html.HtmlOutputText;
+import jakarta.faces.context.FacesContext;
+import jakarta.faces.convert.Converter;
+import jakarta.faces.convert.ConverterException;
 
 import org.apache.myfaces.test.utils.HtmlCheckAttributesUtil;
 import org.apache.myfaces.test.utils.HtmlRenderedAttr;
-import org.apache.myfaces.test.base.AbstractJsfTestCase;
+import org.apache.myfaces.config.webparameters.MyfacesConfig;
+import org.apache.myfaces.test.base.junit.AbstractJsfTestCase;
 import org.apache.myfaces.test.el.MockValueExpression;
 import org.apache.myfaces.test.mock.MockRenderKitFactory;
 import org.apache.myfaces.test.mock.MockResponseWriter;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
  * @author Bruno Aranda (latest modification by $Author$)
@@ -49,23 +51,17 @@ import org.apache.myfaces.test.mock.MockResponseWriter;
 public class HtmlTextRendererTest extends AbstractJsfTestCase
 {
 
-    public static Test suite()
-    {
-        return new TestSuite(HtmlTextRendererTest.class); // needed in maven
-    }
-
     private MockResponseWriter writer ;
     private HtmlOutputText outputText;
     private HtmlInputText inputText;
 
-    public HtmlTextRendererTest(String name)
-    {
-        super(name);
-    }
-
+    @Override
+    @BeforeEach
     public void setUp() throws Exception
     {
         super.setUp();
+ 
+        servletContext.addInitParameter(MyfacesConfig.RENDER_CLIENTBEHAVIOR_SCRIPTS_AS_STRING, "true");
 
         outputText = new HtmlOutputText();
         inputText = new HtmlInputText();
@@ -83,9 +79,11 @@ public class HtmlTextRendererTest extends AbstractJsfTestCase
                 inputText.getRendererType(),
                 new HtmlTextRenderer());
         
-        facesContext.getAttributes().put("org.apache.myfaces.RENDERED_JSF_JS", Boolean.TRUE);
+        facesContext.getAttributes().put("org.apache.myfaces.RENDERED_FACES_JS", Boolean.TRUE);
     }
 
+    @Override
+    @AfterEach
     public void tearDown() throws Exception
     {
         super.tearDown();
@@ -94,6 +92,7 @@ public class HtmlTextRendererTest extends AbstractJsfTestCase
         writer = null;
     }
 
+    @Test
     public void testStyleClassAttr() throws IOException
     {
         outputText.setValue("Output");
@@ -105,14 +104,42 @@ public class HtmlTextRendererTest extends AbstractJsfTestCase
 
         String output = writer.getWriter().toString();
 
-        assertEquals("<span class=\"myStyleClass\">Output</span>", output);
-        assertNotSame("Output", output);
+        Assertions.assertEquals("<span class=\"myStyleClass\">Output</span>", output);
+        Assertions.assertNotSame("Output", output);
     }
+
+    @Test
+    public void testInputDefaultTypeAttr() throws IOException
+    {
+        inputText.encodeBegin(facesContext);
+        inputText.encodeEnd(facesContext);
+        facesContext.renderResponse();
+
+        String output = writer.getWriter().toString();
+        Assertions.assertEquals("<input id=\"j_id__v_0\" name=\"j_id__v_0\" type=\"text\" value=\"\"/>", output);
+        Assertions.assertNotSame("Output", output);
+    }
+
+    @Test
+    public void testInputTypeAttr() throws IOException
+    {
+        inputText.setType("tel");
+
+        inputText.encodeBegin(facesContext);
+        inputText.encodeEnd(facesContext);
+        facesContext.renderResponse();
+
+        String output = writer.getWriter().toString();
+        Assertions.assertEquals("<input id=\"j_id__v_0\" name=\"j_id__v_0\" type=\"tel\" value=\"\"/>", output);
+        Assertions.assertNotSame("Output", output);
+    }
+
     
     /**
      * Don't add span over escape
      * @throws IOException
      */
+    @Test
     public void testEscapeNoSpan() throws IOException
     {
         outputText.setValue("Output");
@@ -124,10 +151,11 @@ public class HtmlTextRendererTest extends AbstractJsfTestCase
 
         String output = writer.getWriter().toString();
 
-        assertEquals("Output", output);
+        Assertions.assertEquals("Output", output);
     }
 
-    public void testHtmlPropertyPassTru() throws Exception
+    @Test
+    public void testHtmlPropertyPassThru() throws Exception
     {
         HtmlRenderedAttr[] attrs = HtmlCheckAttributesUtil.generateBasicAttrs();
         
@@ -135,10 +163,11 @@ public class HtmlTextRendererTest extends AbstractJsfTestCase
         HtmlCheckAttributesUtil.checkRenderedAttributes(
                 inputText, facesContext, writer, attrs);
         if(HtmlCheckAttributesUtil.hasFailedAttrRender(attrs)) {
-            fail(HtmlCheckAttributesUtil.constructErrorMessage(attrs, writer.getWriter().toString()));
+            Assertions.fail(HtmlCheckAttributesUtil.constructErrorMessage(attrs, writer.getWriter().toString()));
         }
     }
     
+    @Test
     public void testWhenSubmittedValueIsNullDefaultShouldDissapearFromRendering() {
         //See MYFACES-2161 and MYFACES-1549 for details
         UIViewRoot root = new UIViewRoot();
@@ -203,13 +232,14 @@ public class HtmlTextRendererTest extends AbstractJsfTestCase
         // 4) renderer calls getValue(); --> getValue() evaluates the
         // value-binding, as the local-value is 'null', and I get the
         // default-value of the bean shown again
-        assertNotSame(expression.getValue(facesContext.getELContext()), inputText.getValue());
-        assertNull(inputText.getValue());
+        Assertions.assertNotSame(expression.getValue(facesContext.getELContext()), inputText.getValue());
+        Assertions.assertNull(inputText.getValue());
     }
     
     /**
      * Components that render client behaviors should always render "id" and "name" attribute
      */
+    @Test
     public void testClientBehaviorHolderRendersIdAndName() 
     {
         inputText.addClientBehavior("keypress", new AjaxBehavior());
@@ -217,12 +247,12 @@ public class HtmlTextRendererTest extends AbstractJsfTestCase
         {
             inputText.encodeAll(facesContext);
             String output = ((StringWriter) writer.getWriter()).getBuffer().toString();
-            assertTrue(output.matches("(?s).+id=\".+\".+"));
-            assertTrue(output.matches("(?s).+name=\".+\".+"));
+            Assertions.assertTrue(output.matches("(?s).+id=\".+\".+"));
+            Assertions.assertTrue(output.matches("(?s).+name=\".+\".+"));
         }
         catch (Exception e)
         {
-            fail(e.getMessage());
+            Assertions.fail(e.getMessage());
         }
         
     }
@@ -231,6 +261,7 @@ public class HtmlTextRendererTest extends AbstractJsfTestCase
      * Tests if a JavaScript user code is correctly escaped.
      * e.g. alert('test') has to become alert(\'test\')
      */
+    @Test
     public void testClientBehaviorUserCodeJavaScriptEscaping()
     {
         inputText.getAttributes().put("onchange", "alert('test')");
@@ -239,13 +270,13 @@ public class HtmlTextRendererTest extends AbstractJsfTestCase
         {
             inputText.encodeAll(facesContext);
             String output = ((StringWriter) writer.getWriter()).getBuffer().toString();
-            // onchange="jsf.util.chain(document.getElementById(&apos;j_id0&apos;), event,
+            // onchange="faces.util.chain(document.getElementById(&apos;j_id0&apos;), event,
             //                          &apos;alert(\&apos;test\&apos;)&apos;);"
-            assertTrue(output.contains("&apos;alert(\\&apos;test\\&apos;)&apos;"));
+            Assertions.assertTrue(output.contains("&apos;alert(\\&apos;test\\&apos;)&apos;"));
         }
         catch (Exception e)
         {
-            fail(e.getMessage());
+            Assertions.fail(e.getMessage());
         }
     }
     
@@ -253,21 +284,22 @@ public class HtmlTextRendererTest extends AbstractJsfTestCase
      * Tests if a JavaScript user code that already contains ' is correctly escaped.
      * e.g. test = 'a\'b'; has to become test = \'a\\\'b\';
      */
+    @Test
     public void testClientBehaviorUserCodeJavaScriptDoubleEscaping()
     {
-        inputText.getAttributes().put("onchange", "var test = \'a\\\'b\'; alert(test);");
+        inputText.getAttributes().put("onchange", "var test = 'a\\'b'; alert(test);");
         inputText.addClientBehavior("change", new AjaxBehavior());
         try 
         {
             inputText.encodeAll(facesContext);
             String output = ((StringWriter) writer.getWriter()).getBuffer().toString();
-            // onchange="jsf.util.chain(document.getElementById(&apos;j_id0&apos;), event,
+            // onchange="faces.util.chain(document.getElementById(&apos;j_id0&apos;), event,
             //               &apos;var test = \&apos;a\\\&apos;b\&apos;; alert(test);&apos;);"
-            assertTrue(output.contains("&apos;var test = \\&apos;a\\\\\\&apos;b\\&apos;; alert(test);&apos;"));
+            Assertions.assertTrue(output.contains("&apos;var test = \\&apos;a\\\\\\&apos;b\\&apos;; alert(test);&apos;"));
         }
         catch (Exception e)
         {
-            fail(e.getMessage());
+            Assertions.fail(e.getMessage());
         }
     }
     
