@@ -20,14 +20,14 @@ package org.apache.myfaces.view.facelets.el;
 
 import java.io.StringWriter;
 import jakarta.el.ExpressionFactory;
-
 import jakarta.faces.component.UIViewRoot;
+
+import org.apache.myfaces.config.webparameters.MyfacesConfig;
 import org.apache.myfaces.test.mock.MockResponseWriter;
 import org.apache.myfaces.view.facelets.ELExpressionCacheMode;
 import org.apache.myfaces.view.facelets.FaceletTestCase;
-import org.apache.myfaces.view.facelets.impl.FaceletCompositionContextImpl;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 /**
  *
@@ -45,7 +45,7 @@ public class CacheELExpressionsTestCase extends FaceletTestCase
     public void testUIParamCaching1() throws Exception
     {
         // Works in "none", "allowCset", and "strict" but it does not in always.
-        servletContext.addInitParameter(FaceletCompositionContextImpl.INIT_PARAM_CACHE_EL_EXPRESSIONS, 
+        servletContext.addInitParameter(MyfacesConfig.CACHE_EL_EXPRESSIONS, 
                 ELExpressionCacheMode.allowCset.toString());
         
         UIViewRoot root = facesContext.getViewRoot();
@@ -57,17 +57,17 @@ public class CacheELExpressionsTestCase extends FaceletTestCase
         
         root.encodeAll(facesContext);
         sw.flush();
-        Assert.assertTrue(sw.toString().contains("ALFA"));
-        Assert.assertTrue(sw.toString().contains("BETA"));
-        Assert.assertTrue(sw.toString().contains("GAMMA"));
-        Assert.assertTrue(sw.toString().contains("OMEGA"));
+        Assertions.assertTrue(sw.toString().contains("ALFA"));
+        Assertions.assertTrue(sw.toString().contains("BETA"));
+        Assertions.assertTrue(sw.toString().contains("GAMMA"));
+        Assertions.assertTrue(sw.toString().contains("OMEGA"));
     }
     
     @Test
     public void testUIParamCaching2() throws Exception
     {
         // Works in "none", "allowCset", and "strict" but it does not in always.
-        servletContext.addInitParameter(FaceletCompositionContextImpl.INIT_PARAM_CACHE_EL_EXPRESSIONS, 
+        servletContext.addInitParameter(MyfacesConfig.CACHE_EL_EXPRESSIONS, 
                 ELExpressionCacheMode.strict.toString());
         
         UIViewRoot root = facesContext.getViewRoot();
@@ -79,10 +79,10 @@ public class CacheELExpressionsTestCase extends FaceletTestCase
         
         root.encodeAll(facesContext);
         sw.flush();
-        Assert.assertTrue(sw.toString().contains("ALFA"));
-        Assert.assertTrue(sw.toString().contains("BETA"));
-        Assert.assertTrue(sw.toString().contains("GAMMA"));
-        Assert.assertTrue(sw.toString().contains("OMEGA"));
+        Assertions.assertTrue(sw.toString().contains("ALFA"));
+        Assertions.assertTrue(sw.toString().contains("BETA"));
+        Assertions.assertTrue(sw.toString().contains("GAMMA"));
+        Assertions.assertTrue(sw.toString().contains("OMEGA"));
     }
 
 }
